[Libreoffice-commits] core.git: include/LibreOfficeKit

Pranav Kant pranavk at collabora.co.uk
Wed Oct 25 16:35:09 UTC 2017


 include/LibreOfficeKit/LibreOfficeKit.hxx |   51 +++++++++++++++++++++++++++++-
 1 file changed, 50 insertions(+), 1 deletion(-)

New commits:
commit f2e707baa762e9a4d80116cc6d6fc246eafeca3e
Author: Pranav Kant <pranavk at collabora.co.uk>
Date:   Wed Oct 25 09:31:46 2017 -0700

    lokdialog: Add more dialog related methods to LOK API
    
    Change-Id: I0e4abb38e1ea9450ae9c50f71ac6e8f9150868ae

diff --git a/include/LibreOfficeKit/LibreOfficeKit.hxx b/include/LibreOfficeKit/LibreOfficeKit.hxx
index 9e897c5ffb85..e573a88249a9 100644
--- a/include/LibreOfficeKit/LibreOfficeKit.hxx
+++ b/include/LibreOfficeKit/LibreOfficeKit.hxx
@@ -175,6 +175,25 @@ public:
     }
 
     /**
+     * Renders the active floating window of a dialog
+     *
+     * Client must truncate pBuffer according to the nWidth and nHeight returned after the call.
+     *
+     * @param pDialogId Unique dialog id
+     * @param pBuffer Buffer with enough memory allocated to render any dialog
+     * @param nWidth output parameter returning the width of the rendered dialog.
+     * @param nHeight output parameter returning the height of the rendered dialog
+     */
+    void paintActiveFloatingWindow(const char* pDialogId,
+                                   unsigned char* pBuffer,
+                                   int& nWidth,
+                                   int& nHeight)
+    {
+        return mpDoc->pClass->paintActiveFloatingWindow(mpDoc, pDialogId, pBuffer,
+                                                        &nWidth, &nHeight);
+    }
+
+    /**
      * Gets the tile mode: the pixel format used for the pBuffer of paintTile().
      *
      * @return an element of the LibreOfficeKitTileMode enum.
@@ -240,6 +259,19 @@ public:
     }
 
     /**
+     * Posts a keyboard event to the dialog
+     *
+     * @param pDialogId Dialog id on which key event should be posted
+     * @param nType Event type, like press or release.
+     * @param nCharCode contains the Unicode character generated by this event or 0
+     * @param nKeyCode contains the integer code representing the key of the event (non-zero for control keys)
+     */
+    void postDialogKeyEvent(const char* pDialogId, int nType, int nCharCode, int nKeyCode)
+    {
+        mpDoc->pClass->postDialogKeyEvent(mpDoc, pDialogId, nType, nCharCode, nKeyCode);
+    }
+
+    /**
      * Posts a mouse event to the document.
      *
      * @param nType Event type, like down, move or up.
@@ -257,7 +289,7 @@ public:
     /**
      * Posts a mouse event to the dialog with given id.
      *
      * @param aDialogId Dialog id where mouse event is to be posted
      * @param nType Event type, like down, move or up.
      * @param nX horizontal position in document coordinates
      * @param nY vertical position in document coordinates
@@ -271,6 +303,23 @@ public:
     }
 
     /**
+     * Posts a mouse event to the child of a dialog with given id.
+     *
+     * @param aDialogId Dialog id
+     * @param nType Event type, like down, move or up.
+     * @param nX horizontal position in document coordinates
+     * @param nY vertical position in document coordinates
+     * @param nCount number of clicks: 1 for single click, 2 for double click
+     * @param nButtons: which mouse buttons: 1 for left, 2 for middle, 4 right
+     * @param nModifier: which keyboard modifier: (see include/vcl/vclenum.hxx for possible values)
+     */
+    void postDialogChildMouseEvent(const char* pDialogId, int nType, int nX, int nY, int nCount, int nButtons, int nModifier)
+    {
+        mpDoc->pClass->postDialogChildMouseEvent(mpDoc, pDialogId, nType, nX, nY, nCount, nButtons, nModifier);
+    }
+
+
+    /**
      * Posts an UNO command to the document.
      *
      * Example argument string:
@@ -257,7 +289,7 @@ public:
      * Posts a mouse event to the dialog with given id.
      *
-     * @param aDialogId Dialog id where mouse event is to be posted
+     * @param pDialogId Dialog id where mouse event is to be posted
      * @param nType Event type, like down, move or up.
      * @param nX horizontal position in document coordinates


More information about the Libreoffice-commits mailing list